package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 哈密瓜API接单
 */
@Service
@Slf4j
public class HamiguaCreditService implements LoanDockingApi {
    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "/v1/api/customer/repeat/check";

    private final String applyPath = "/v1/api/customer/media/create";

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Hamigua;
    }

    @Data
    public static class CheckData{
        private String mobile_md5;
        private String city;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer code;
        private String message;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit HamiguaCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject hamiguaJointDTO = JSON.parseObject(configJson);
            log.info("哈密瓜对接参数:{}", JSON.toJSONString(hamiguaJointDTO));
//            CheckInfo checkInfo = new CheckInfo();
            CheckData checkData = new CheckData();
            checkData.setCity(userInfo.getCompanyCity());
            checkData.setMobile_md5(userInfo.getPhoneMd5());
//            checkInfo.setClient_id(hamiguaJointDTO.getClientId());
//            checkInfo.setClient_secret(hamiguaJointDTO.getClientSecret());
//            checkInfo.setData(checkData);
            String url = hamiguaJointDTO.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck HamiguaCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url, checkData);
            ResultHt response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/json");
                head.put("secret", hamiguaJointDTO.getString("clientSecret"));
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, JSON.toJSONString(checkData));
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr,ResultHt.class);
            }catch (Exception e){
                log.error("哈密瓜准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HamiguaCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals(10, response.getCode()) ? DataVo.success(0, "哈密瓜撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMessage(), product.getPlanId());
        } catch (Exception e) {
            log.error("哈密瓜撞库失败", e);
            return DataVo.fail(1, "哈密瓜撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
