package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/27
 * @Version V1.0
 **/
@Slf4j
@Service
public class OpenApiCreditService implements LoanDockingApi {

    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final static String IV="go9yPim47avSQZ8m";


    @Data
    private static class CheckInfo {
        private String channelCode = "hrsk";

        private String city;

        private String phoneMd5;
    }

    @Data
    private static class Result {
        private Integer code;
        private String msg;
        private JSONObject data;
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        log.info("credit OpenApiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
        try {
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            if (StringUtils.isAnyEmpty(apiInfo.getOpenapiCheckUrl(), apiInfo.getOpenapiAccessKeySecret())) {
                return DataVo.fail(product.getPlanName(), product.getPlanId());
            }
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(userInfo.getPhoneMd5());
            checkInfo.setCity(userInfo.getCompanyCity());
            String url = apiInfo.getOpenapiCheckUrl();
            log.info("credit qualityCheck OpenApiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            Result response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, Result.class);
            } catch (Exception e) {
                log.error("OpenAPI准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck OpenApiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(0, response.getCode()) && Objects.equals(0, response.getData().getInteger("status")) ?
                    DataVo.success(0, "OpenAPI撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());

        } catch (Exception e) {
            log.error("OpenAPI撞库失败", e);
            return DataVo.fail(1, "OpenAPI撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.OPEN_API;
    }

}
