package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;

/**
 * 欣客贷API接单
 */
@Service
@Slf4j
public class XinkedaiCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/admin/pushApi/check_mobile";
    private final String applyPath = "/admin/pushApi/import_tttg";
    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.Xinkedai;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"url":"http://121.40.173.17:8811"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit XingkedaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("欣客贷对接参数:{}", JSON.toJSONString(config));
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            String phoneMd5 = userInfo.getPhoneMd5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getPhoneMd5();
            params.add("mobile", phoneMd5);
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck XingkedaiCreditService request userId:{}, url:{}, params:{}",userInfo.getUserId(), url, JSON.toJSONString(params));
            ResponseEntity<String> response = null;
            try{
                HttpEntity<MultiValueMap<String, String>> requestEntity = new HttpEntity<MultiValueMap<String, String>>(params, headers);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class);
            }catch (Exception e){
                log.error("欣客贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XingkedaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null || response.getStatusCode()!= HttpStatus.OK) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return JSON.parseObject(response.getBody()).getInteger("code") ==0 ? DataVo.success(0, "欣客贷撞库成功", product.getPlanId())
                    : DataVo.fail("撞库失败", product.getPlanId());

        } catch (Exception e) {
            log.error("欣客贷撞库失败", e);
            return DataVo.fail(1, "欣客贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
