package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * 信易贷API接单
 */
@Service
@Slf4j
public class XinyidaiCreditService implements LoanDockingApi {
    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "/api/customer/md5check";

    private final String applyPath = "/api/customer/add";
    @Value("${spring.profiles.active}")
    private String activeProfile;



    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.Xinyidai;
    }


    @Data
    public static class CheckData{
        private String mobile_md5;
        private String city;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer code;
        private String message;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit XinyidaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject xinyidaiJointDTO = JSON.parseObject(configJson);
            log.info("信易贷对接参数:{}", JSON.toJSONString(xinyidaiJointDTO));
            String url = xinyidaiJointDTO.getString("url") + qualityCheckPath+"?md5=" +userInfo.getPhoneMd5() ;
            log.info("credit qualityCheck XinyidaiCreditService request userId:{}, url:{}",userInfo.getUserId(), url);
            ResultHt response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded");
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, "");
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr,ResultHt.class);
            }catch (Exception e){
                log.error("信易贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XinyidaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals(12, response.getCode()) ? DataVo.success(0, "信易贷撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMessage(), product.getPlanId());
        } catch (Exception e) {
            log.error("信易贷撞库失败", e);
            return DataVo.fail(1, "信易贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
}
