package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 06 13 14 50
 **/
@Slf4j
@Service
public class YiBangDaiCreditService implements LoanDockingApi {

    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.YiBangDaiCreditService;
    }
    @Data
    private static class CheckInfo{
        private String mobile;// 手机号md5
    }
    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit FuChengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("壹帮贷对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getPhoneMd5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getPhoneMd5();
            Map<String, String> requestData = new HashMap<>();
            requestData.put("mobile", phoneMd5);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck FuChengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            JSONObject response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded");
                head.put("token", config.getString("token"));
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, requestData);
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr);
            }catch (Exception e){
                log.error("壹帮贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck FuChengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getInteger("code")==1) {
                String data = response.getString("data");
                JSONObject datas = JSONObject.parseObject(data);
                if (datas.getInteger("status")==0){
                    return DataVo.success(0, "壹帮贷撞库成功", product.getPlanId());
                }else {
                    return DataVo.fail(1, "壹帮贷撞库失败，请联系系统管理员", product.getPlanId());
                }
            } else {
                return DataVo.fail(1, "壹帮贷撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "壹帮贷撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
