package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/6
 * @Version V1.0
 **/
@Slf4j
@Service
public class YukuaihuaCreditService implements LoanDockingApi {

    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final static String checkPath = "api/External/hit_library";
    private final static String applyPath = "api/External/create";

    @Data
    private static class Result {
        private Integer code;

        private String msg;

        private Long time;

        private Object data;
    }

    @Data
    private static class CheckInfo {
        private String userPhone;
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit YukuaihuaCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("愉快花对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setUserPhone(userInfo.getPhoneMd5());
            String url = config.getString("url") + checkPath;
            log.info("credit qualityCheck YukuaihuaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            Result response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, Result.class);
            } catch (Exception e) {
                log.error("愉快花准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YukuaihuaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(1, response.getCode()) ? DataVo.success(0, "愉快花撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());

        } catch (Exception e) {
            log.error("愉快花撞库失败", e);
            return DataVo.fail(1, "愉快花撞库失败，请联系系统管理员", product.getPlanId());
        }
    }
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YuKuaiHua;
    }

}
